# BeWeAsset

BeWeAsset is a side project from Berlin Hsin. The project aims to start some quantive investment research.

Related jira can be found in https://beweasset.atlassian.net/jira/software/projects/BW/boards/3 .